@@ -91,27 +91,35 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_RDF_TYPE_ATMA
 	LDNS_RDF_TYPE_B32_EXT
 	LDNS_RDF_TYPE_B64
+	LDNS_RDF_TYPE_BITMAP
 	LDNS_RDF_TYPE_CERT_ALG
+	LDNS_RDF_TYPE_CERTIFICATE_USAGE
 	LDNS_RDF_TYPE_CLASS
 	LDNS_RDF_TYPE_DNAME
+	LDNS_RDF_TYPE_EUI48
+	LDNS_RDF_TYPE_EUI64
 	LDNS_RDF_TYPE_HEX
+	LDNS_RDF_TYPE_HIP
+	LDNS_RDF_TYPE_ILNP64
 	LDNS_RDF_TYPE_INT16
 	LDNS_RDF_TYPE_INT16_DATA
 	LDNS_RDF_TYPE_INT32
 	LDNS_RDF_TYPE_INT8
 	LDNS_RDF_TYPE_IPSECKEY
 	LDNS_RDF_TYPE_LOC
-	LDNS_RDF_TYPE_LONG
+	LDNS_RDF_TYPE_LONG_STR
+	LDNS_RDF_TYPE_MATCHING_TYPE
 	LDNS_RDF_TYPE_NONE
 	LDNS_RDF_TYPE_NSAP
 	LDNS_RDF_TYPE_NSEC
 	LDNS_RDF_TYPE_NSEC3_NEXT_OWNER
 	LDNS_RDF_TYPE_NSEC3_SALT
 	LDNS_RDF_TYPE_PERIOD
+	LDNS_RDF_TYPE_SELECTOR
 	LDNS_RDF_TYPE_SERVICE
 	LDNS_RDF_TYPE_STR
+	LDNS_RDF_TYPE_TAG
 	LDNS_RDF_TYPE_TIME
-	LDNS_RDF_TYPE_HIP
 	LDNS_RDF_TYPE_TSIGTIME
 	LDNS_RDF_TYPE_TYPE
 	LDNS_RDF_TYPE_UNKNOWN
@@ -147,16 +155,23 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_RR_TYPE_ANY
 	LDNS_RR_TYPE_APL
 	LDNS_RR_TYPE_ATMA
+	LDNS_RR_TYPE_AVC
 	LDNS_RR_TYPE_AXFR
+	LDNS_RR_TYPE_CAA
+	LDNS_RR_TYPE_CDNSKEY
+	LDNS_RR_TYPE_CDS
 	LDNS_RR_TYPE_CERT
 	LDNS_RR_TYPE_CNAME
 	LDNS_RR_TYPE_COUNT
+	LDNS_RR_TYPE_CSYNC
 	LDNS_RR_TYPE_DHCID
 	LDNS_RR_TYPE_DLV
 	LDNS_RR_TYPE_DNAME
 	LDNS_RR_TYPE_DNSKEY
 	LDNS_RR_TYPE_DS
 	LDNS_RR_TYPE_EID
+	LDNS_RR_TYPE_EUI48
+	LDNS_RR_TYPE_EUI64
 	LDNS_RR_TYPE_FIRST
 	LDNS_RR_TYPE_GID
 	LDNS_RR_TYPE_GPOS
@@ -166,8 +181,11 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_RR_TYPE_IXFR
 	LDNS_RR_TYPE_KEY
 	LDNS_RR_TYPE_KX
+	LDNS_RR_TYPE_L32
+	LDNS_RR_TYPE_L64
 	LDNS_RR_TYPE_LAST
 	LDNS_RR_TYPE_LOC
+	LDNS_RR_TYPE_LP
 	LDNS_RR_TYPE_MAILA
 	LDNS_RR_TYPE_MAILB
 	LDNS_RR_TYPE_MB
@@ -178,7 +196,9 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_RR_TYPE_MR
 	LDNS_RR_TYPE_MX
 	LDNS_RR_TYPE_NAPTR
+	LDNS_RR_TYPE_NID
 	LDNS_RR_TYPE_NIMLOC
+	LDNS_RR_TYPE_NINFO
 	LDNS_RR_TYPE_NS
 	LDNS_RR_TYPE_NSAP
 	LDNS_RR_TYPE_NSAP_PTR
@@ -188,24 +208,31 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_RR_TYPE_NSEC3PARAMS
 	LDNS_RR_TYPE_NULL
 	LDNS_RR_TYPE_NXT
+	LDNS_RR_TYPE_OPENPGPKEY
 	LDNS_RR_TYPE_OPT
 	LDNS_RR_TYPE_PTR
 	LDNS_RR_TYPE_PX
+	LDNS_RR_TYPE_RKEY
 	LDNS_RR_TYPE_RP
 	LDNS_RR_TYPE_RRSIG
 	LDNS_RR_TYPE_RT
 	LDNS_RR_TYPE_SIG
 	LDNS_RR_TYPE_SINK
+	LDNS_RR_TYPE_SMIMEA
 	LDNS_RR_TYPE_SOA
 	LDNS_RR_TYPE_SPF
 	LDNS_RR_TYPE_SRV
 	LDNS_RR_TYPE_SSHFP
+	LDNS_RR_TYPE_TA
 	LDNS_RR_TYPE_TALINK
+	LDNS_RR_TYPE_TKEY
+	LDNS_RR_TYPE_TLSA
 	LDNS_RR_TYPE_TSIG
 	LDNS_RR_TYPE_TXT
 	LDNS_RR_TYPE_UID
 	LDNS_RR_TYPE_UINFO
 	LDNS_RR_TYPE_UNSPEC
+	LDNS_RR_TYPE_URI
 	LDNS_RR_TYPE_WKS
 	LDNS_RR_TYPE_X25
 	LDNS_RSAMD5
@@ -228,8 +255,14 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_SIGN_DSA
 	LDNS_SIGN_DSA_NSEC3
 	LDNS_SIGN_ECC_GOST
+	LDNS_SIGN_ECDSAP256SHA256
+	LDNS_SIGN_ECDSAP384SHA384
+	LDNS_SIGN_HMACMD5
 	LDNS_SIGN_HMACSHA1
+	LDNS_SIGN_HMACSHA224
 	LDNS_SIGN_HMACSHA256
+	LDNS_SIGN_HMACSHA384
+	LDNS_SIGN_HMACSHA512
 	LDNS_SIGN_RSAMD5
 	LDNS_SIGN_RSASHA1
 	LDNS_SIGN_RSASHA1_NSEC3
@@ -247,12 +280,30 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_STATUS_CRYPTO_NO_TRUSTED_DNSKEY
 	LDNS_STATUS_CRYPTO_NO_TRUSTED_DS
 	LDNS_STATUS_CRYPTO_SIG_EXPIRED
+        LDNS_STATUS_CRYPTO_SIG_EXPIRED_WITHIN_MARGIN
 	LDNS_STATUS_CRYPTO_SIG_NOT_INCEPTED
+        LDNS_STATUS_CRYPTO_SIG_NOT_INCEPTED_WITHIN_MARGIN
 	LDNS_STATUS_CRYPTO_TSIG_BOGUS
 	LDNS_STATUS_CRYPTO_TSIG_ERR
 	LDNS_STATUS_CRYPTO_TYPE_COVERED_ERR
 	LDNS_STATUS_CRYPTO_UNKNOWN_ALGO
 	LDNS_STATUS_CRYPTO_VALIDATED
+        LDNS_STATUS_DANE_BOGUS
+        LDNS_STATUS_DANE_EXTRA_CERTS_NOT_USED
+        LDNS_STATUS_DANE_INSECURE
+        LDNS_STATUS_DANE_MISSING_EXTRA_CERTS
+        LDNS_STATUS_DANE_NEED_OPENSSL_GE_1_1_FOR_DANE_TA
+        LDNS_STATUS_DANE_NON_CA_CERTIFICATE
+        LDNS_STATUS_DANE_OFFSET_OUT_OF_RANGE
+        LDNS_STATUS_DANE_PKIX_DID_NOT_VALIDATE
+        LDNS_STATUS_DANE_PKIX_NO_SELF_SIGNED_TRUST_ANCHOR
+        LDNS_STATUS_DANE_STATUS_MESSAGES
+        LDNS_STATUS_DANE_TLSA_DID_NOT_MATCH
+        LDNS_STATUS_DANE_UNKNOWN_CERTIFICATE_USAGE
+        LDNS_STATUS_DANE_UNKNOWN_MATCHING_TYPE
+        LDNS_STATUS_DANE_UNKNOWN_PROTOCOL
+        LDNS_STATUS_DANE_UNKNOWN_SELECTOR
+        LDNS_STATUS_DANE_UNKNOWN_TRANSPORT
 	LDNS_STATUS_DDD_OVERFLOW
 	LDNS_STATUS_DNSSEC_EXISTENCE_DENIED
 	LDNS_STATUS_DNSSEC_NSEC3_ORIGINAL_NOT_FOUND
@@ -263,16 +314,22 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_STATUS_EMPTY_LABEL
 	LDNS_STATUS_ENGINE_KEY_NOT_LOADED
 	LDNS_STATUS_ERR
+        LDNS_STATUS_EXISTS_ERR
 	LDNS_STATUS_FILE_ERR
 	LDNS_STATUS_INTERNAL_ERR
 	LDNS_STATUS_INVALID_B32_EXT
 	LDNS_STATUS_INVALID_B64
+        LDNS_STATUS_INVALID_EUI48
+        LDNS_STATUS_INVALID_EUI64
 	LDNS_STATUS_INVALID_HEX
+        LDNS_STATUS_INVALID_ILNP64
 	LDNS_STATUS_INVALID_INT
 	LDNS_STATUS_INVALID_IP4
 	LDNS_STATUS_INVALID_IP6
 	LDNS_STATUS_INVALID_POINTER
+        LDNS_STATUS_INVALID_RDF_TYPE
 	LDNS_STATUS_INVALID_STR
+        LDNS_STATUS_INVALID_TAG
 	LDNS_STATUS_INVALID_TIME
 	LDNS_STATUS_LABEL_OVERFLOW
 	LDNS_STATUS_MEM_ERR
@@ -281,10 +338,12 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_STATUS_NETWORK_ERR
 	LDNS_STATUS_NOT_IMPL
 	LDNS_STATUS_NO_DATA
+        LDNS_STATUS_NSEC3_DOMAINNAME_OVERFLOW
 	LDNS_STATUS_NSEC3_ERR
 	LDNS_STATUS_NULL
 	LDNS_STATUS_OK
 	LDNS_STATUS_PACKET_OVERFLOW
+        LDNS_STATUS_RDATA_OVERFLOW
 	LDNS_STATUS_RES_NO_NS
 	LDNS_STATUS_RES_QUERY
 	LDNS_STATUS_SOCKET_ERROR
@@ -303,6 +362,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw(
 	LDNS_STATUS_SYNTAX_MISSING_VALUE_ERR
 	LDNS_STATUS_SYNTAX_ORIGIN
 	LDNS_STATUS_SYNTAX_RDATA_ERR
+        LDNS_STATUS_SYNTAX_SUPERFLUOUS_TEXT_ERR
 	LDNS_STATUS_SYNTAX_TTL
 	LDNS_STATUS_SYNTAX_TTL_ERR
 	LDNS_STATUS_SYNTAX_TYPE_ERR
@@ -412,26 +472,35 @@ our @EXPORT = qw(
 	LDNS_RDF_TYPE_ATMA
 	LDNS_RDF_TYPE_B32_EXT
 	LDNS_RDF_TYPE_B64
+        LDNS_RDF_TYPE_BITMAP
 	LDNS_RDF_TYPE_CERT_ALG
+        LDNS_RDF_TYPE_CERTIFICATE_USAGE
 	LDNS_RDF_TYPE_CLASS
 	LDNS_RDF_TYPE_DNAME
+        LDNS_RDF_TYPE_EUI48
+        LDNS_RDF_TYPE_EUI64
 	LDNS_RDF_TYPE_HEX
+        LDNS_RDF_TYPE_HIP
+        LDNS_RDF_TYPE_ILNP64
 	LDNS_RDF_TYPE_INT16
 	LDNS_RDF_TYPE_INT16_DATA
 	LDNS_RDF_TYPE_INT32
 	LDNS_RDF_TYPE_INT8
 	LDNS_RDF_TYPE_IPSECKEY
 	LDNS_RDF_TYPE_LOC
+        LDNS_RDF_TYPE_LONG_STR
+        LDNS_RDF_TYPE_MATCHING_TYPE
 	LDNS_RDF_TYPE_NONE
 	LDNS_RDF_TYPE_NSAP
 	LDNS_RDF_TYPE_NSEC
 	LDNS_RDF_TYPE_NSEC3_NEXT_OWNER
 	LDNS_RDF_TYPE_NSEC3_SALT
 	LDNS_RDF_TYPE_PERIOD
+        LDNS_RDF_TYPE_SELECTOR
 	LDNS_RDF_TYPE_SERVICE
 	LDNS_RDF_TYPE_STR
+        LDNS_RDF_TYPE_TAG
 	LDNS_RDF_TYPE_TIME
-	LDNS_RDF_TYPE_HIP
 	LDNS_RDF_TYPE_TSIGTIME
 	LDNS_RDF_TYPE_TYPE
 	LDNS_RDF_TYPE_UNKNOWN
@@ -467,16 +536,23 @@ our @EXPORT = qw(
 	LDNS_RR_TYPE_ANY
 	LDNS_RR_TYPE_APL
 	LDNS_RR_TYPE_ATMA
+        LDNS_RR_TYPE_AVC
 	LDNS_RR_TYPE_AXFR
+        LDNS_RR_TYPE_CAA
+        LDNS_RR_TYPE_CDNSKEY
+        LDNS_RR_TYPE_CDS
 	LDNS_RR_TYPE_CERT
 	LDNS_RR_TYPE_CNAME
 	LDNS_RR_TYPE_COUNT
+        LDNS_RR_TYPE_CSYNC
 	LDNS_RR_TYPE_DHCID
 	LDNS_RR_TYPE_DLV
 	LDNS_RR_TYPE_DNAME
 	LDNS_RR_TYPE_DNSKEY
 	LDNS_RR_TYPE_DS
 	LDNS_RR_TYPE_EID
+        LDNS_RR_TYPE_EUI48
+        LDNS_RR_TYPE_EUI64
 	LDNS_RR_TYPE_FIRST
 	LDNS_RR_TYPE_GID
 	LDNS_RR_TYPE_GPOS
@@ -486,8 +562,11 @@ our @EXPORT = qw(
 	LDNS_RR_TYPE_IXFR
 	LDNS_RR_TYPE_KEY
 	LDNS_RR_TYPE_KX
+        LDNS_RR_TYPE_L32
+        LDNS_RR_TYPE_L64
 	LDNS_RR_TYPE_LAST
 	LDNS_RR_TYPE_LOC
+        LDNS_RR_TYPE_LP
 	LDNS_RR_TYPE_MAILA
 	LDNS_RR_TYPE_MAILB
 	LDNS_RR_TYPE_MB
@@ -498,7 +577,9 @@ our @EXPORT = qw(
 	LDNS_RR_TYPE_MR
 	LDNS_RR_TYPE_MX
 	LDNS_RR_TYPE_NAPTR
+        LDNS_RR_TYPE_NID
 	LDNS_RR_TYPE_NIMLOC
+        LDNS_RR_TYPE_NINFO
 	LDNS_RR_TYPE_NS
 	LDNS_RR_TYPE_NSAP
 	LDNS_RR_TYPE_NSAP_PTR
@@ -508,24 +589,31 @@ our @EXPORT = qw(
 	LDNS_RR_TYPE_NSEC3PARAMS
 	LDNS_RR_TYPE_NULL
 	LDNS_RR_TYPE_NXT
+        LDNS_RR_TYPE_OPENPGPKEY
 	LDNS_RR_TYPE_OPT
 	LDNS_RR_TYPE_PTR
 	LDNS_RR_TYPE_PX
+        LDNS_RR_TYPE_RKEY
 	LDNS_RR_TYPE_RP
 	LDNS_RR_TYPE_RRSIG
 	LDNS_RR_TYPE_RT
 	LDNS_RR_TYPE_SIG
 	LDNS_RR_TYPE_SINK
+        LDNS_RR_TYPE_SMIMEA
 	LDNS_RR_TYPE_SOA
 	LDNS_RR_TYPE_SPF
 	LDNS_RR_TYPE_SRV
 	LDNS_RR_TYPE_SSHFP
+        LDNS_RR_TYPE_TA
 	LDNS_RR_TYPE_TALINK
+        LDNS_RR_TYPE_TKEY
+        LDNS_RR_TYPE_TLSA
 	LDNS_RR_TYPE_TSIG
 	LDNS_RR_TYPE_TXT
 	LDNS_RR_TYPE_UID
 	LDNS_RR_TYPE_UINFO
 	LDNS_RR_TYPE_UNSPEC
+        LDNS_RR_TYPE_URI
 	LDNS_RR_TYPE_WKS
 	LDNS_RR_TYPE_X25
 	LDNS_RSAMD5
@@ -548,8 +636,14 @@ our @EXPORT = qw(
 	LDNS_SIGN_DSA
 	LDNS_SIGN_DSA_NSEC3
 	LDNS_SIGN_ECC_GOST
+        LDNS_SIGN_ECDSAP256SHA256
+        LDNS_SIGN_ECDSAP384SHA384
+        LDNS_SIGN_HMACMD5
 	LDNS_SIGN_HMACSHA1
-	LDNS_SIGN_HMACSHA256
+        LDNS_SIGN_HMACSHA224
+        LDNS_SIGN_HMACSHA256
+        LDNS_SIGN_HMACSHA384
+        LDNS_SIGN_HMACSHA512
 	LDNS_SIGN_RSAMD5
 	LDNS_SIGN_RSASHA1
 	LDNS_SIGN_RSASHA1_NSEC3
@@ -567,12 +661,30 @@ our @EXPORT = qw(
 	LDNS_STATUS_CRYPTO_NO_TRUSTED_DNSKEY
 	LDNS_STATUS_CRYPTO_NO_TRUSTED_DS
 	LDNS_STATUS_CRYPTO_SIG_EXPIRED
+        LDNS_STATUS_CRYPTO_SIG_EXPIRED_WITHIN_MARGIN
 	LDNS_STATUS_CRYPTO_SIG_NOT_INCEPTED
+        LDNS_STATUS_CRYPTO_SIG_NOT_INCEPTED_WITHIN_MARGIN
 	LDNS_STATUS_CRYPTO_TSIG_BOGUS
 	LDNS_STATUS_CRYPTO_TSIG_ERR
 	LDNS_STATUS_CRYPTO_TYPE_COVERED_ERR
 	LDNS_STATUS_CRYPTO_UNKNOWN_ALGO
 	LDNS_STATUS_CRYPTO_VALIDATED
+        LDNS_STATUS_DANE_BOGUS
+        LDNS_STATUS_DANE_EXTRA_CERTS_NOT_USED
+        LDNS_STATUS_DANE_INSECURE
+        LDNS_STATUS_DANE_MISSING_EXTRA_CERTS
+        LDNS_STATUS_DANE_NEED_OPENSSL_GE_1_1_FOR_DANE_TA
+        LDNS_STATUS_DANE_NON_CA_CERTIFICATE
+        LDNS_STATUS_DANE_OFFSET_OUT_OF_RANGE
+        LDNS_STATUS_DANE_PKIX_DID_NOT_VALIDATE
+        LDNS_STATUS_DANE_PKIX_NO_SELF_SIGNED_TRUST_ANCHOR
+        LDNS_STATUS_DANE_STATUS_MESSAGES
+        LDNS_STATUS_DANE_TLSA_DID_NOT_MATCH
+        LDNS_STATUS_DANE_UNKNOWN_CERTIFICATE_USAGE
+        LDNS_STATUS_DANE_UNKNOWN_MATCHING_TYPE
+        LDNS_STATUS_DANE_UNKNOWN_PROTOCOL
+        LDNS_STATUS_DANE_UNKNOWN_SELECTOR
+        LDNS_STATUS_DANE_UNKNOWN_TRANSPORT
 	LDNS_STATUS_DDD_OVERFLOW
 	LDNS_STATUS_DNSSEC_EXISTENCE_DENIED
 	LDNS_STATUS_DNSSEC_NSEC3_ORIGINAL_NOT_FOUND
@@ -583,16 +695,22 @@ our @EXPORT = qw(
 	LDNS_STATUS_EMPTY_LABEL
 	LDNS_STATUS_ENGINE_KEY_NOT_LOADED
 	LDNS_STATUS_ERR
+        LDNS_STATUS_EXISTS_ERR
 	LDNS_STATUS_FILE_ERR
 	LDNS_STATUS_INTERNAL_ERR
 	LDNS_STATUS_INVALID_B32_EXT
 	LDNS_STATUS_INVALID_B64
+        LDNS_STATUS_INVALID_EUI48
+        LDNS_STATUS_INVALID_EUI64
 	LDNS_STATUS_INVALID_HEX
+        LDNS_STATUS_INVALID_ILNP64
 	LDNS_STATUS_INVALID_INT
 	LDNS_STATUS_INVALID_IP4
 	LDNS_STATUS_INVALID_IP6
 	LDNS_STATUS_INVALID_POINTER
+        LDNS_STATUS_INVALID_RDF_TYPE
 	LDNS_STATUS_INVALID_STR
+        LDNS_STATUS_INVALID_TAG
 	LDNS_STATUS_INVALID_TIME
 	LDNS_STATUS_LABEL_OVERFLOW
 	LDNS_STATUS_MEM_ERR
@@ -601,10 +719,12 @@ our @EXPORT = qw(
 	LDNS_STATUS_NETWORK_ERR
 	LDNS_STATUS_NOT_IMPL
 	LDNS_STATUS_NO_DATA
+        LDNS_STATUS_NSEC3_DOMAINNAME_OVERFLOW
 	LDNS_STATUS_NSEC3_ERR
 	LDNS_STATUS_NULL
 	LDNS_STATUS_OK
 	LDNS_STATUS_PACKET_OVERFLOW
+        LDNS_STATUS_RDATA_OVERFLOW
 	LDNS_STATUS_RES_NO_NS
 	LDNS_STATUS_RES_QUERY
 	LDNS_STATUS_SOCKET_ERROR
@@ -623,6 +743,7 @@ our @EXPORT = qw(
 	LDNS_STATUS_SYNTAX_MISSING_VALUE_ERR
 	LDNS_STATUS_SYNTAX_ORIGIN
 	LDNS_STATUS_SYNTAX_RDATA_ERR
+        LDNS_STATUS_SYNTAX_SUPERFLUOUS_TEXT_ERR
 	LDNS_STATUS_SYNTAX_TTL
 	LDNS_STATUS_SYNTAX_TTL_ERR
 	LDNS_STATUS_SYNTAX_TYPE_ERR
@@ -652,7 +773,7 @@ our @EXPORT = qw(
 	read_anchor_file
 );
 
-our $VERSION = '0.62';
+our $VERSION = '0.63';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -725,29 +846,29 @@ DNS::LDNS - Perl extension for the ldns library
 DNS::LDNS is a perl OO-wrapper for the ldns library. A complete list
 of object methods is found in the perldoc for each of the individual
 classes. You may also read the documentation of the ldns library
-(http://www.nlnetlabs.nl/projects/ldns). 
+(http://www.nlnetlabs.nl/projects/ldns).
 
 =head2 Brief examples of usage
 
   use DNS::LDNS ':all';
 
-  my $z = new DNS::LDNS::Zone(filename => '/path/to/myzone');
+  my $z = DNS::LDNS::Zone->new(filename => '/path/to/myzone');
   print DNS::LDNS::last_error;
-  my $rr = new DNS::LDNS::RR('mylabel 3600 IN A 168.10.10.10');
+  my $rr = DNS::LDNS::RR->new('mylabel 3600 IN A 168.10.10.10');
   print $z->soa->to_string;
   my $rrlist = $z->rrs->push($rr);
   print $z->to_string;
 
-  my $kl = new DNS::LDNS::KeyList;
-  $kl->push(new DNS::LDNS::Key(filename => 'key');
+  my $kl = DNS::LDNS::KeyList->new;
+  $kl->push(DNS::LDNS::Key->new(filename => 'key');
   $kl->key(0)->set_pubkey_owner(
-      new DNS::LDNS::RData(LDNS_RDF_TYPE_DNAME, 'myzone.org'));
+      DNS::LDNS::RData->new(LDNS_RDF_TYPE_DNAME, 'myzone.org'));
   my $signedz = $z->sign($kl);
   print $signedz->to_string;
 
-  my $r = new DNS::LDNS::Resolver(filename => '/my/resolv.conf');
+  my $r = DNS::LDNS::Resolver->new(filename => '/my/resolv.conf');
   my $p = $r->send(
-    new DNS::LDNS::RData(LDNS_RDF_TYPE_DNAME, 'www.google.com'), 
+    DNS::LDNS::RData->new(LDNS_RDF_TYPE_DNAME, 'www.google.com'),
     LDNS_RR_TYPE_A, LDNS_RR_CLASS_IN, LDNS_RD);
   print $p->answer->to_string;
   print $p->authority->to_string;
@@ -864,7 +985,7 @@ zone in a more structured way.
   rr = dnssec_create_nsec(from, to, type)
   rr = dnssec_create_nsec3(from, to, algorithm, flags, iterations, salt)
   rr = create_nsec(current, next, rrs)
-  rr = create_nsec3(cur_owner, cur_zone, algorithm, flags, 
+  rr = create_nsec3(cur_owner, cur_zone, algorithm, flags,
                     iterations, salt, empty_nonterminals)
   algo = signing_algorithm_by_name(name)
   bool = key_algorithm_supported(algorithm)
@@ -884,7 +1005,7 @@ really want.
 
 DNS::LDNS::Zone::rrs returns a reference to the DNS::LDNS::RRList
 within  the zone, so if you make changes to the RRList you also
-changes the Zone  object. 
+changes the Zone  object.
 
 DNS::LDNS::RRList::push(rr) clones the rr, then pushes the cloned rr
 to the  list. Changing the rr afterwards will not change the list.
@@ -903,382 +1024,20 @@ The purpose for writing this wrapper class has been to be able to
 process zone file data with good time performance. Data checking and
 error handling is a bit sparse.
 
-Most constructors will update the DNS::LDNS::last_status variable if 
-they fail (return undef). Wrapper methods to ldns functions which would 
-return a status will update the static DNS::LDNS::last_status variable. 
-Most methods do not return a status and will not reset this variable 
+Most constructors will update the DNS::LDNS::last_status variable if
+they fail (return undef). Wrapper methods to ldns functions which would
+return a status will update the static DNS::LDNS::last_status variable.
+Most methods do not return a status and will not reset this variable
 even though they succeeds.
 
 =head2 EXPORT
 
 None by default.
 
-=head2 Exportable constants
-
-=head3 Status
-
-  LDNS_STATUS_ADDRESS_ERR
-  LDNS_STATUS_CERT_BAD_ALGORITHM
-  LDNS_STATUS_CRYPTO_ALGO_NOT_IMPL
-  LDNS_STATUS_CRYPTO_BOGUS
-  LDNS_STATUS_CRYPTO_EXPIRATION_BEFORE_INCEPTION
-  LDNS_STATUS_CRYPTO_NO_DNSKEY
-  LDNS_STATUS_CRYPTO_NO_DS
-  LDNS_STATUS_CRYPTO_NO_MATCHING_KEYTAG_DNSKEY
-  LDNS_STATUS_CRYPTO_NO_RRSIG
-  LDNS_STATUS_CRYPTO_NO_TRUSTED_DNSKEY
-  LDNS_STATUS_CRYPTO_NO_TRUSTED_DS
-  LDNS_STATUS_CRYPTO_SIG_EXPIRED
-  LDNS_STATUS_CRYPTO_SIG_NOT_INCEPTED
-  LDNS_STATUS_CRYPTO_TSIG_BOGUS
-  LDNS_STATUS_CRYPTO_TSIG_ERR
-  LDNS_STATUS_CRYPTO_TYPE_COVERED_ERR
-  LDNS_STATUS_CRYPTO_UNKNOWN_ALGO
-  LDNS_STATUS_CRYPTO_VALIDATED
-  LDNS_STATUS_DDD_OVERFLOW
-  LDNS_STATUS_DNSSEC_EXISTENCE_DENIED
-  LDNS_STATUS_DNSSEC_NSEC3_ORIGINAL_NOT_FOUND
-  LDNS_STATUS_DNSSEC_NSEC_RR_NOT_COVERED
-  LDNS_STATUS_DNSSEC_NSEC_WILDCARD_NOT_COVERED
-  LDNS_STATUS_DOMAINNAME_OVERFLOW
-  LDNS_STATUS_DOMAINNAME_UNDERFLOW
-  LDNS_STATUS_EMPTY_LABEL
-  LDNS_STATUS_ENGINE_KEY_NOT_LOADED
-  LDNS_STATUS_ERR
-  LDNS_STATUS_FILE_ERR
-  LDNS_STATUS_INTERNAL_ERR
-  LDNS_STATUS_INVALID_B32_EXT
-  LDNS_STATUS_INVALID_B64
-  LDNS_STATUS_INVALID_HEX
-  LDNS_STATUS_INVALID_INT
-  LDNS_STATUS_INVALID_IP4
-  LDNS_STATUS_INVALID_IP6
-  LDNS_STATUS_INVALID_POINTER
-  LDNS_STATUS_INVALID_STR
-  LDNS_STATUS_INVALID_TIME
-  LDNS_STATUS_LABEL_OVERFLOW
-  LDNS_STATUS_MEM_ERR
-  LDNS_STATUS_MISSING_RDATA_FIELDS_KEY
-  LDNS_STATUS_MISSING_RDATA_FIELDS_RRSIG
-  LDNS_STATUS_NETWORK_ERR
-  LDNS_STATUS_NOT_IMPL
-  LDNS_STATUS_NO_DATA
-  LDNS_STATUS_NSEC3_ERR
-  LDNS_STATUS_NULL
-  LDNS_STATUS_OK
-  LDNS_STATUS_PACKET_OVERFLOW
-  LDNS_STATUS_RES_NO_NS
-  LDNS_STATUS_RES_QUERY
-  LDNS_STATUS_SOCKET_ERROR
-  LDNS_STATUS_SSL_ERR
-  LDNS_STATUS_SYNTAX_ALG_ERR
-  LDNS_STATUS_SYNTAX_BAD_ESCAPE
-  LDNS_STATUS_SYNTAX_CLASS_ERR
-  LDNS_STATUS_SYNTAX_DNAME_ERR
-  LDNS_STATUS_SYNTAX_EMPTY
-  LDNS_STATUS_SYNTAX_ERR
-  LDNS_STATUS_SYNTAX_INCLUDE
-  LDNS_STATUS_SYNTAX_INCLUDE_ERR_NOTIMPL
-  LDNS_STATUS_SYNTAX_INTEGER_OVERFLOW
-  LDNS_STATUS_SYNTAX_ITERATIONS_OVERFLOW
-  LDNS_STATUS_SYNTAX_KEYWORD_ERR
-  LDNS_STATUS_SYNTAX_MISSING_VALUE_ERR
-  LDNS_STATUS_SYNTAX_ORIGIN
-  LDNS_STATUS_SYNTAX_RDATA_ERR
-  LDNS_STATUS_SYNTAX_TTL
-  LDNS_STATUS_SYNTAX_TTL_ERR
-  LDNS_STATUS_SYNTAX_TYPE_ERR
-  LDNS_STATUS_SYNTAX_VERSION_ERR
-  LDNS_STATUS_UNKNOWN_INET
-  LDNS_STATUS_WIRE_INCOMPLETE_ADDITIONAL
-  LDNS_STATUS_WIRE_INCOMPLETE_ANSWER
-  LDNS_STATUS_WIRE_INCOMPLETE_AUTHORITY
-  LDNS_STATUS_WIRE_INCOMPLETE_HEADER
-  LDNS_STATUS_WIRE_INCOMPLETE_QUESTION
-
-=head3 Resolver flags and constants
-
-  LDNS_RESOLV_ANCHOR
-  LDNS_RESOLV_DEFDOMAIN
-  LDNS_RESOLV_INET
-  LDNS_RESOLV_INET6
-  LDNS_RESOLV_INETANY
-  LDNS_RESOLV_KEYWORD
-  LDNS_RESOLV_KEYWORDS
-  LDNS_RESOLV_NAMESERVER
-  LDNS_RESOLV_OPTIONS
-  LDNS_RESOLV_RTT_INF
-  LDNS_RESOLV_RTT_MIN
-  LDNS_RESOLV_SEARCH
-  LDNS_RESOLV_SORTLIST
-
-=head3 Resolver query flags
-
-  LDNS_AA
-  LDNS_AD
-  LDNS_CD
-  LDNS_QR
-  LDNS_RA
-  LDNS_RD
-  LDNS_TC
-
-=head3 Resolver rcodes
-
-  LDNS_RCODE_FORMERR
-  LDNS_RCODE_NOERROR
-  LDNS_RCODE_NOTAUTH
-  LDNS_RCODE_NOTIMPL
-  LDNS_RCODE_NOTZONE
-  LDNS_RCODE_NXDOMAIN
-  LDNS_RCODE_NXRRSET
-  LDNS_RCODE_REFUSED
-  LDNS_RCODE_SERVFAIL
-  LDNS_RCODE_YXDOMAIN
-  LDNS_RCODE_YXRRSET
-
-=head3 Packet types
-
-  LDNS_PACKET_ANSWER
-  LDNS_PACKET_NODATA
-  LDNS_PACKET_NXDOMAIN
-  LDNS_PACKET_QUESTION
-  LDNS_PACKET_REFERRAL
-  LDNS_PACKET_UNKNOWN
-
-=head3 Packet opcodes
-
-  LDNS_PACKET_IQUERY
-  LDNS_PACKET_NOTIFY
-  LDNS_PACKET_QUERY
-  LDNS_PACKET_STATUS
-  LDNS_PACKET_UPDATE
-
-=head3 Packet sections
-
-  LDNS_SECTION_ADDITIONAL
-  LDNS_SECTION_ANSWER
-  LDNS_SECTION_ANY
-  LDNS_SECTION_ANY_NOQUESTION
-  LDNS_SECTION_AUTHORITY
-  LDNS_SECTION_QUESTION
-
-=head3 DNSSec constants
-
-  LDNS_DEFAULT_EXP_TIME
-  LDNS_MAX_KEYLEN
-  LDNS_DNSSEC_KEYPROTO
-
-=head3 DNSSec sign policies
-
-  LDNS_SIGNATURE_LEAVE_ADD_NEW
-  LDNS_SIGNATURE_LEAVE_NO_ADD
-  LDNS_SIGNATURE_REMOVE_ADD_NEW
-  LDNS_SIGNATURE_REMOVE_NO_ADD
-  LDNS_NSEC3_MAX_ITERATIONS
-
-=head3 Key flags
-
-  LDNS_KEY_REVOKE_KEY
-  LDNS_KEY_SEP_KEY
-  LDNS_KEY_ZONE_KEY
-
-=head3 Key algorithms
-
-  LDNS_DH
-  LDNS_DSA
-  LDNS_DSA_NSEC3
-  LDNS_ECC
-  LDNS_RSAMD5
-  LDNS_RSASHA1
-  LDNS_RSASHA1_NSEC3
-  LDNS_RSASHA256
-  LDNS_RSASHA512
-  LDNS_ECC_GOST
-  LDNS_PRIVATEDNS
-  LDNS_PRIVATEOID
-
-=head3 Signing algorithms
-
-  LDNS_SIGN_DSA
-  LDNS_SIGN_DSA_NSEC3
-  LDNS_SIGN_ECC_GOST
-  LDNS_SIGN_HMACSHA1
-  LDNS_SIGN_HMACSHA256
-  LDNS_SIGN_RSAMD5
-  LDNS_SIGN_RSASHA1
-  LDNS_SIGN_RSASHA1_NSEC3
-  LDNS_SIGN_RSASHA256
-  LDNS_SIGN_RSASHA512
-
-=head3 Hashing algorithm
-
-  LDNS_SHA1
-  LDNS_SHA256
-  LDNS_HASH_GOST
-
-=head3 Rdata constants
-
-  LDNS_MAX_RDFLEN
-  LDNS_NSEC3_VARS_OPTOUT_MASK
-
-  LDNS_RDF_SIZE_16BYTES
-  LDNS_RDF_SIZE_6BYTES
-  LDNS_RDF_SIZE_BYTE
-  LDNS_RDF_SIZE_DOUBLEWORD
-  LDNS_RDF_SIZE_WORD
-
-=head3 Rdata types
-
-  LDNS_RDF_TYPE_A
-  LDNS_RDF_TYPE_AAAA
-  LDNS_RDF_TYPE_ALG
-  LDNS_RDF_TYPE_APL
-  LDNS_RDF_TYPE_ATMA
-  LDNS_RDF_TYPE_B32_EXT
-  LDNS_RDF_TYPE_B64
-  LDNS_RDF_TYPE_CERT_ALG
-  LDNS_RDF_TYPE_CLASS
-  LDNS_RDF_TYPE_DNAME
-  LDNS_RDF_TYPE_HEX
-  LDNS_RDF_TYPE_INT16
-  LDNS_RDF_TYPE_INT16_DATA
-  LDNS_RDF_TYPE_INT32
-  LDNS_RDF_TYPE_INT8
-  LDNS_RDF_TYPE_IPSECKEY
-  LDNS_RDF_TYPE_LOC
-  LDNS_RDF_TYPE_NONE
-  LDNS_RDF_TYPE_NSAP
-  LDNS_RDF_TYPE_NSEC
-  LDNS_RDF_TYPE_NSEC3_NEXT_OWNER
-  LDNS_RDF_TYPE_NSEC3_SALT
-  LDNS_RDF_TYPE_PERIOD
-  LDNS_RDF_TYPE_SERVICE
-  LDNS_RDF_TYPE_STR
-  LDNS_RDF_TYPE_TIME
-  LDNS_RDF_TYPE_HIP
-  LDNS_RDF_TYPE_TSIGTIME
-  LDNS_RDF_TYPE_TYPE
-  LDNS_RDF_TYPE_UNKNOWN
-  LDNS_RDF_TYPE_WKS
-
-=head3 Algorithms used in CERT RRs.
-
-  LDNS_CERT_ACPKIX
-  LDNS_CERT_IACPKIX
-  LDNS_CERT_IPGP
-  LDNS_CERT_IPKIX
-  LDNS_CERT_ISPKI
-  LDNS_CERT_OID
-  LDNS_CERT_PGP
-  LDNS_CERT_PKIX
-  LDNS_CERT_SPKI
-  LDNS_CERT_URI
-
-=head3 RR compress flag
-
-  LDNS_RR_COMPRESS
-  LDNS_RR_NO_COMPRESS
-
-=head3 RR classes
-
-  LDNS_RR_CLASS_ANY
-  LDNS_RR_CLASS_CH
-  LDNS_RR_CLASS_COUNT
-  LDNS_RR_CLASS_FIRST
-  LDNS_RR_CLASS_HS
-  LDNS_RR_CLASS_IN
-  LDNS_RR_CLASS_LAST
-  LDNS_RR_CLASS_NONE
-
-=head3 RR types
-
-  LDNS_RR_TYPE_A
-  LDNS_RR_TYPE_A6
-  LDNS_RR_TYPE_AAAA
-  LDNS_RR_TYPE_AFSDB
-  LDNS_RR_TYPE_ANY
-  LDNS_RR_TYPE_APL
-  LDNS_RR_TYPE_ATMA
-  LDNS_RR_TYPE_AXFR
-  LDNS_RR_TYPE_CERT
-  LDNS_RR_TYPE_CNAME
-  LDNS_RR_TYPE_COUNT
-  LDNS_RR_TYPE_DHCID
-  LDNS_RR_TYPE_DLV
-  LDNS_RR_TYPE_DNAME
-  LDNS_RR_TYPE_DNSKEY
-  LDNS_RR_TYPE_DS
-  LDNS_RR_TYPE_EID
-  LDNS_RR_TYPE_FIRST
-  LDNS_RR_TYPE_GID
-  LDNS_RR_TYPE_GPOS
-  LDNS_RR_TYPE_HINFO
-  LDNS_RR_TYPE_IPSECKEY
-  LDNS_RR_TYPE_ISDN
-  LDNS_RR_TYPE_IXFR
-  LDNS_RR_TYPE_KEY
-  LDNS_RR_TYPE_KX
-  LDNS_RR_TYPE_LAST
-  LDNS_RR_TYPE_LOC
-  LDNS_RR_TYPE_MAILA
-  LDNS_RR_TYPE_MAILB
-  LDNS_RR_TYPE_MB
-  LDNS_RR_TYPE_MD
-  LDNS_RR_TYPE_MF
-  LDNS_RR_TYPE_MG
-  LDNS_RR_TYPE_MINFO
-  LDNS_RR_TYPE_MR
-  LDNS_RR_TYPE_MX
-  LDNS_RR_TYPE_NAPTR
-  LDNS_RR_TYPE_NIMLOC
-  LDNS_RR_TYPE_NS
-  LDNS_RR_TYPE_NSAP
-  LDNS_RR_TYPE_NSAP_PTR
-  LDNS_RR_TYPE_NSEC
-  LDNS_RR_TYPE_NSEC3
-  LDNS_RR_TYPE_NSEC3PARAM
-  LDNS_RR_TYPE_NSEC3PARAMS
-  LDNS_RR_TYPE_NULL
-  LDNS_RR_TYPE_NXT
-  LDNS_RR_TYPE_OPT
-  LDNS_RR_TYPE_PTR
-  LDNS_RR_TYPE_PX
-  LDNS_RR_TYPE_RP
-  LDNS_RR_TYPE_RRSIG
-  LDNS_RR_TYPE_RT
-  LDNS_RR_TYPE_SIG
-  LDNS_RR_TYPE_SINK
-  LDNS_RR_TYPE_SOA
-  LDNS_RR_TYPE_SPF
-  LDNS_RR_TYPE_SRV
-  LDNS_RR_TYPE_SSHFP
-  LDNS_RR_TYPE_TALINK
-  LDNS_RR_TYPE_TSIG
-  LDNS_RR_TYPE_TXT
-  LDNS_RR_TYPE_UID
-  LDNS_RR_TYPE_UINFO
-  LDNS_RR_TYPE_UNSPEC
-  LDNS_RR_TYPE_WKS
-  LDNS_RR_TYPE_X25
-
-=head3 Various defaults and other constants
-
-  LDNS_DEFAULT_TTL
-  LDNS_PORT
-  LDNS_IP4ADDRLEN
-  LDNS_IP6ADDRLEN
-  LDNS_MAX_DOMAINLEN
-  LDNS_MAX_LABELLEN
-  LDNS_MAX_PACKETLEN
-  LDNS_MAX_POINTERS
-  LDNS_RR_OVERHEAD
-  LDNS_RDATA_FIELD_DESCRIPTORS_COMMON
-
 =head1 BUGS
 
-This package is still in the beta stage of development. There no known bugs, 
-although parts of the code has not yet been very well tested. Bugreports will 
-be greatly appreciated.
+There no known bugs, although parts of the code has not yet been very
+well tested. Bugreports will be greatly appreciated.
 
 =head1 SEE ALSO
 
@@ -1286,7 +1045,7 @@ http://www.nlnetlabs.nl/projects/ldns
 
 =head1 AUTHOR
 
-Erik Pihl Ostlyngen, E<lt>erik.ostlyngen@uninett.noE<gt>
+Erik Pihl Ostlyngen, E<lt>erik.ostlyngen@norid.noE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
