@@ -4,9 +4,9 @@ use 5.008008;
 use strict;
 use warnings;
 
-use DNS::LDNS;
+use DNS::LDNS ();
 
-our $VERSION = '0.62';
+our $VERSION = '0.63';
 
 sub new {
     my ($class, %args) = @_;
@@ -55,7 +55,7 @@ sub push_list {
 
 sub verify {
     my ($self, $sig, $keys) = @_;
-    my $goodkeys = new DNS::LDNS::RRList;
+    my $goodkeys = DNS::LDNS::RRList->new;
     my $s = _verify($self, $sig, $keys, $goodkeys);
     $DNS::LDNS::last_status = $s;
     return wantarray ? ($s, $goodkeys) : $s;
@@ -63,7 +63,7 @@ sub verify {
 
 sub verify_time {
     my ($self, $sig, $keys, $checktime) = @_;
-    my $goodkeys = new DNS::LDNS::RRList;
+    my $goodkeys = DNS::LDNS::RRList->new;
     my $s = _verify_time($self, $sig, $keys, $checktime, $goodkeys);
     $DNS::LDNS::last_status = $s;
     return wantarray ? ($s, $goodkeys) : $s;
@@ -71,7 +71,7 @@ sub verify_time {
 
 sub verify_notime {
     my ($self, $sig, $keys) = @_;
-    my $goodkeys = new DNS::LDNS::RRList;
+    my $goodkeys = DNS::LDNS::RRList->new;
     my $s = _verify_notime($self, $sig, $keys, $goodkeys);
     $DNS::LDNS::last_status = $s;
     return wantarray ? ($s, $goodkeys) : $s;
@@ -79,7 +79,7 @@ sub verify_notime {
 
 sub verify_rrsig_keylist {
     my ($self, $sig, $keys) = @_;
-    my $goodkeys = new DNS::LDNS::RRList;
+    my $goodkeys = DNS::LDNS::RRList->new;
     my $s = _verify_rrsig_keylist($self, $sig, $keys, $goodkeys);
     $DNS::LDNS::last_status = $s;
     return wantarray ? ($s, $goodkeys) : $s;
@@ -87,7 +87,7 @@ sub verify_rrsig_keylist {
 
 sub verify_rrsig_keylist_notime {
     my ($self, $sig, $keys, $check_time) = @_;
-    my $goodkeys = new DNS::LDNS::RRList;
+    my $goodkeys = DNS::LDNS::RRList->new;
     my $s = _verify_rrsig_keylist_notime($self, $sig, $keys, $goodkeys);
     $DNS::LDNS::last_status = $s;
     return wantarray ? ($s, $goodkeys) : $s;
@@ -117,11 +117,11 @@ DNS::LDNS::RRList - List of rrs
 
 =head1 SYNOPSIS
 
-  use DNS::LDNS ':all'
+  use DNS::LDNS ();
 
-  my l = new DNS::LDNS::RRList
-  my l = new DNS::LDNS::RRList(hosts_file => \*FILE)
-  my l = new DNS::LDNS::RRList(hosts_filename => fname)
+  my l = DNS::LDNS::RRList->new
+  my l = DNS::LDNS::RRList->new(hosts_file => \*FILE)
+  my l = DNS::LDNS::RRList->new(hosts_filename => fname)
   my l2 = l->clone
 
   l->to_string
